/* @clake/react-bootstrap4-window v0.1.4 | by Clake
 * Copyright (c) 2018 Clake,
 * 2018-11-13T15:34:03+0800
 */
"use strict";

Object.defineProperty(exports, "__esModule", {
    value: true
});
var _arguments = arguments;

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; };

/**
 * extend object
 * @param org
 * @param exd
 */
var extend = exports.extend = function extend(org, exd) {
    if ((typeof exd === "undefined" ? "undefined" : _typeof(exd)) === "object") {
        for (var key in org) {
            org[key] = exd[key];
        }
    }
    return org;
};

/**
 * random string
 * @param str_length
 * @param tab
 * @returns {string}
 * @constructor
 */
var RandomString = exports.RandomString = function RandomString(str_length) {
    var tab = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : "0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz";

    var num = void 0,
        out_str = "";

    for (var i = 0; i < str_length; i++) {
        num = Math.round(Math.random() * tab.length);
        out_str += tab.substring(num, num + 1);
    }

    return out_str;
};

/**
 * dynamic loading script or css file
 * @type {{_loaded: {}, load: LoadScript.load}}
 */
var LoadScript = exports.LoadScript = {
    _loaded: {},
    load: function load(srcStr, strID) {
        var func = arguments[2];
        var version = arguments[3];
        if (this._loaded[strID]) {
            if (func && typeof func === "function") func();
            return;
        }
        var element = void 0;
        var ext = srcStr.split('?')[0].substr(srcStr.lastIndexOf('.') + 1);
        if (ext === 'css') {
            element = document.createElement("LINK");
            if (typeof version === "string") {
                element.href = srcStr + "?" + version;
            } else if (typeof version === "boolean") {
                element.href = srcStr + "?" + RandomString(5);
            } else {
                element.href = srcStr;
            }
            element.rel = 'stylesheet';
            element.id = strID;
            element.type = 'text/css';
        } else if (ext === 'js') {
            element = document.createElement("SCRIPT");
            if (typeof version === "string") {
                element.src = srcStr + "?" + version;
            } else if (typeof version === "boolean") {
                element.src = srcStr + "?" + RandomString(5);
            } else {
                element.src = srcStr;
            }
            element.type = 'text/javascript';
            element.id = strID;
            element.language = 'javascript';
        }

        this._loaded[strID] = false;
        var self = this;
        element.onload = function () {
            this.onload = null;
            self._loaded[strID] = true;
            if (func && typeof func === "function") func();
        };
        element.onerror = function () {
            alert("Load Library Error!");
        };

        document.getElementsByTagName("head")[0].appendChild(element);
        element = null;
    }
};

/**
 * get html dom element position
 * @param e
 * @param parent
 * @returns {{top: number, left: number, height: number, width: number}}
 * @constructor
 */
var GetDomXY = exports.GetDomXY = function GetDomXY(e, parent) {
    var t = {
        top: e.offsetTop,
        left: e.offsetLeft,
        height: e.clientHeight,
        width: e.clientWidth
    };
    var scrollTop = 0;
    var scrollLeft = 0;
    var topScroll = 0;
    var leftScroll = 0;
    while ((e = e.offsetParent) && e !== parent) {
        t['top'] += e.offsetTop;
        t['left'] += e.offsetLeft;
        topScroll = e.scrollTop;
        scrollTop += topScroll;
        leftScroll = e.scrollLeft;
        scrollLeft += leftScroll;
    }
    t['top'] = t['top'] - (scrollTop - topScroll);
    t['left'] = t['left'] - (scrollLeft - leftScroll);

    scrollTop = topScroll = scrollLeft = leftScroll = parent = null;
    return t;
};

/**
 * get current screen DPI size
 * @returns {Array}
 * @constructor
 */
var GetDPI = exports.GetDPI = function GetDPI() {
    var arrDPI = [];
    if (window.screen.deviceXDPI) {
        arrDPI[0] = window.screen.deviceXDPI;
        arrDPI[1] = window.screen.deviceYDPI;
    } else {
        var tmpNode = document.createElement("DIV");
        tmpNode.style.cssText = "width:1in;height:1in;position:absolute;left:0px;top:0px;z-index:99;visibility:hidden";
        document.body.appendChild(tmpNode);
        arrDPI[0] = parseInt(tmpNode.offsetWidth);
        arrDPI[1] = parseInt(tmpNode.offsetHeight);
        tmpNode.parentNode.removeChild(tmpNode);
    }
    return arrDPI;
};

/**
 * has object in array
 * @param needle
 * @param haystack
 * @returns {boolean}
 * @constructor
 */
var InArray = exports.InArray = function InArray(needle, haystack) {
    if (typeof needle === 'string' || typeof needle === 'number') {
        for (var i in haystack) {
            if (haystack[i] === needle) {
                return true;
            }
        }
    }
    return false;
};
/**
 * Map object
 * @param obj
 * @param func
 * @returns {Array}
 */
var map = exports.map = function map(obj, func) {
    if ((typeof obj === "undefined" ? "undefined" : _typeof(obj)) !== 'object') {
        return [];
    }
    if (typeof func !== 'function') {
        return [];
    }
    var list = [];
    var idx = 0;
    for (var k in obj) {
        list.push(func(obj[k], k, idx));
        idx++;
    }
    return list;
};

var str_pad = exports.str_pad = function str_pad(text, length, padstring) {
    var type = _arguments[3] || "left";
    text += '';
    padstring += '';
    var padtext = null;
    if (text.length < length) {
        padtext = padstring;

        while (padtext.length < length - text.length) {
            padtext += padstring;
        }
        if (type === "left") {
            text = padtext.substr(0, length - text.length) + text;
        } else if (type === "right") {
            text = text + padtext.substr(0, length - text.length);
        }
    }
    padtext = null;
    return text;
};

exports.default = {
    extend: extend,
    GetDomXY: GetDomXY,
    InArray: InArray,
    GetDPI: GetDPI,
    LoadScript: LoadScript,
    RandomString: RandomString,
    map: map,
    strpad: str_pad
};
//# sourceMappingURL=Common.js.map
